#
# spec file for package python-hotdoc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-hotdoc
Version:        0.16
Release:        1.4
Summary:        A documentation tool micro-framework
License:        LGPL-2.1-or-later
Group:          Development/Tools/Doc Generators
URL:            https://github.com/hotdoc/hotdoc
Source:         https://files.pythonhosted.org/packages/source/h/hotdoc/hotdoc-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module setuptools}
BuildRequires:  clang
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  glib2-devel
BuildRequires:  json-glib-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  libyaml-devel
BuildRequires:  llvm-devel
BuildRequires:  python-rpm-macros
# The c extension needs libclang.so and llvm-config
Requires:       clang-devel
Requires:       llvm-devel
Requires:       python-PyYAML >= 5.4.1
Requires:       python-appdirs
Requires:       python-cchardet
Requires:       python-dbus-deviation >= 0.6.1
Requires:       python-feedgen
Requires:       python-lxml >= 4.9.1
Requires:       python-networkx >= 2.8.8
Requires:       python-pkgconfig >= 1.5.1
Requires:       python-schema
Requires:       python-toposort >= 1.6
Requires:       python-wheezy.template >= 0.1.195
Requires(post): update-alternatives
%if "%{python_flavor}" == "python3" || "%{?python_provides}" == "python3"
# The hotdoc cli files were provided as separate package between Aug and Nov 2020
Obsoletes:      hotdoc < %{version}-%{release}
Provides:       hotdoc = %{version}-%{release}
%endif
%python_subpackages

%description
Hotdoc is a documentation framework. It provides an interface for extensions
to plug upon, along with some base objects (formatters, ...)

Hotdoc is distributed with a set of extensions that perform various tasks,
such as parsing C and extracting symbols with clang, parsing
gobject-introspection (gir) files, highlighting the syntax of code snippets
with prism, etc.

%prep
%setup -q -n hotdoc-%{version}
sed -i -e "s/wheezy.template==/wheezy.template>=/" setup.py
sed -i -e "s/pkgconfig==/pkgconfig>=/" setup.py
sed -i -e "s/networkx==/networkx>=/" setup.py

sed -i -e '1s,#! %{_bindir}/env sh,#!%{_bindir}/sh,' ./hotdoc/extensions/gi/transition_scripts/translate_sections.sh

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/hotdoc
%python_clone -a %{buildroot}%{_bindir}/hotdoc_dep_printer
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%post
%python_install_alternative hotdoc hotdoc_dep_printer

%postun
%python_uninstall_alternative hotdoc

%files %{python_files}
%license COPYING
%doc README.md
%{python_sitearch}/hotdoc
%{python_sitearch}/hotdoc-%{version}*-info
%python_alternative %{_bindir}/hotdoc
%python_alternative %{_bindir}/hotdoc_dep_printer

%changelog
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.16:
  * `scanners.re` - fixed warnings; use `*` for fallback.
  * Fixed some warnings in `scanners.re`.
  * Update CaseFolding to latest (Kevin Wojniak, #168).
  * Allow balanced nested parens in link destinations (Yuki
    Izumi, #166)
  * Allocate enough bytes for backticks array.
  * Inlines: Ensure that the delimiter stack is freed in subject.
* Tue May 30 2023 Mia Herkt <mia@0x0.st>
- Update to 0.15
  + formatter: allow for light and dark stylesheets
  + theme: add light mode variables (lumen)
  + extension: output unescaped sitemap
- 0.14.1 release
  + gtk_doc: look for devhelp indexes in more places
  + devhelp: Exclude useless files
  + hotdoc_dep_printer: fix Config class name
  + wheezy.template usage: switch to maintainer-recommended
    workaround
  + setup: fix build with python 3.11
  + Switch from charset-normalizer to faust-cchardet
  + Adding tarfile member sanitization to extractall()
- 0.14.0 release
  + requirements: bump networkx and dbus-deviation versions
  + Regenerate requirements.txt with flex installed
  + build(deps): bump lxml from 4.6.3 to 4.9.1
  + Switch unmaintained ccharset to charset-normalizer
  + enum_member: render Since tag
  + symbols: do not list aliases as children
  + extensions: simple ATOM feed generator
  + base_symbol: format tags for all symbols
- 0.13.7 release
  + gi: ignore more boilerplate macros
- 0.13.6 release
  + update cmark submodule
  + gtkdoc_extension: fix out of bounds access
- 0.13.5 release
  + Fix incorrect use of hashlib and cache
  + ext: Allow loading extension modules with full paths
    gh#hotdoc/hotdoc#235
  + Add some documentation for the metadata keys
- 0.13.4 release
  + signals: store callbacks in OrderedSets
  + gi-extension: ignore boilerplate macros for enums and bitfields too
  + Add option for enabling prism-keep-markup
  + tree: fix picking of page output path
  + Print an error message instead of segfaulting.
  + CI: use pip for editable installs
  + build(deps): bump lxml from 4.6.2 to 4.6.3
* Tue Mar 30 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to 0.13.3:
  + No changelog
  + gi_extension: don't ignore callbacks in structs
  + gi: Add class structure fields as children of the
    GIInterfaceSymbol
  + symbols: Do not override field symbol comment with None
  + gi: Add class structure fields as children of the GIClassSymbol
  + aliases: fix link resolution
- 0.13.2 release
  + Update theme submodule
  + ProxySymbol: do not override the title of the proxied symbol
  + symbols: not all children symbols need formatting
  + templates: check-in forgotten action prototypes
- 0.13.1 release
  + setup.py: distribute comment_on_github assets
- 0.13.0 release
  + Update theme submodule
  + Implement a separate symbol type for action signals
  + gst: make use of gi-extension languages
  + add frozen list of used packages via pip-compile
  + setup.py: remove check on __name__ == '__main__'
  + drop dependency on xdg
  + future-proof networkx dependency by dropping explicit pinning
  + fix DeprecationWarnings for collections.abc
  + unpin wheezy.template dependency
  + remove unneeded pin on python-pkgconfig version
  + CI: replace travis with github workflow
  + gi: remove FundamentalSymbol
  + Fix GitHub capitalization on "Edit on GitHub button"
  + Update networkx to 2.5
  + gi_extension: fix page gi-languages
  + search_module: don't consider '-' a word separator
  + Add comment on github extension
  + Update theme submodule ￼…
  + Update theme submodule
  + license_extension: allow theme and extension to advertise
    licensing
  + search_module: fix context id identification
  + gtk_doc: Support annotation lines ended with colons
  + database: Allow aliases to have the same name as a real symbol
  + gst: Use plugin name to reference plugins
  + gst: Move other class types to their own pages
  + gst: Fix previous commit that shadow 'prop' variable by mistake
  + gst: Associate objects with their children and plugins with
    other types
  + check_since_markers: remove stray print
  + gi: associate klass with its chilren symbols
- Remove patch which is no longer needed:
  * remove-dependency-on-python-xdg.patch
* Sat Mar 20 2021 Ben Greiner <code@bnavigator.de>
- Avoid have-choice with upcoming python39 flavor: Only provide the
  hotdoc capability without python prefix by primary python3
  package.
* Wed Feb 10 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Fix typo in previous commit (defnie -> define).
* Wed Feb 10 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not build for python 3.6: not all dependencies are available
  and compatible to Python 3.6.
* Tue Nov  3 2020 Benjamin Greiner <code@bnavigator.de>
- Reinclude the cli files under update-alternatives control into
  the main package in order to support multiple python3 flavors
  gh#openSUSE/python-rpm-macros#66
* Thu Oct 22 2020 Antonio Larrosa <alarrosa@suse.com>
- Add Requires: python-setuptools
* Fri Oct 16 2020 Antonio Larrosa <alarrosa@suse.com>
- Add patch to remove dependency on python-xdg and use python-pyxdg
  instead since both are not coinstallable and pyxdg is a
  freedesktop project and used by openSUSE-release-tools:
  * remove-dependency-on-python-xdg.patch
* Thu Sep 17 2020 Antonio Larrosa <alarrosa@suse.com>
- Fix rpm group
* Mon Aug  3 2020 Antonio Larrosa <alarrosa@suse.com>
- Initial release of python-hotdoc 0.12.2
